api.customers.v1 package — Argus-Toolbelt 1.0 documentation

# api.customers.v1 package

## Submodules

## api.customers.v1.customer module

Autogenerated API

`api.customers.v1.customer.` `add_customer`(name: str = None, shortName: str = None, properties: dict = None, logoURL: str = None, accountManagerID: int = None, features: list = None, language: str = 'ENGLISH', timeZone: str = 'Europe/Oslo', type: str = 'CUSTOMER', parentID: int = 0, excludeFromProduction: bool = 'False', json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Create a new customer (PUBLIC)

  Return type: | `dict`
  Parameters: | name (str) – Name to set for new customer. => [sw{}$-().[]“‘_/,*+#:@!?;]* shortName (str) – shortName to set for new customer (must be unique). => [a-zA-Z0-9_-.]* properties (dict) – Properties to set for customer. => [sw{}$-().[]“‘_/,*+#:@!?;]* logoURL (str) – Customer logo data url. On format data:image/jpeg;base64,BASE64STRING. => Sanitize by regex data:.* accountManagerID (int) – ID of account manager to assign to customer. If not set, no account manager is set. features (list) – Features to enable on customer. language (str) – Language to set for customer. (default ENGLISH) timeZone (str) – Name of timezone to set for customer. (default Europe/Oslo) type (str) – Object type. If set to GROUP, this customer can have subcustomers. (default CUSTOMER) parentID (int) – ID of parent customer group to add this customer to. (default 0) excludeFromProduction (bool) – Mark customer as excluded from production. (default false)
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403 ObjectNotFoundException – on 404
  Returns: | {“offset”: 122, “limit”: 248, “responseCode”: 200, “count”: 151, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Federal major have need attorney foreign especially.”, “messageTemplate”: “Where it throughout oil.”, “field”: “People argue series performance dinner cause.”, “parameter”: {}, “timestamp”: 192731732}], “currentPage”: 992, “size”: 537}

`api.customers.v1.customer.` `add_customer_service`(customerID: int, service: str = None, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Add a service to a customer. (PUBLIC)

  Return type: | `dict`
  Parameters: | customerID (int) – Customer ID service (str) – Name of service to enable on customer
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403 ObjectNotFoundException – on 404
  Returns: | {“offset”: 756, “limit”: 544, “responseCode”: 200, “count”: 800, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Choose law call quality upon.”, “messageTemplate”: “Not certainly wonder interview mean.”, “field”: “Serve reflect can key father service.”, “parameter”: {}, “timestamp”: 1319149462}], “currentPage”: 640, “size”: 43}

`api.customers.v1.customer.` `disable_customer`(id: int, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Disable customer. (PUBLIC)

  Return type: | `dict`
  Parameters: | id (int) – Customer ID
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403 ObjectNotFoundException – on 404
  Returns: | {“offset”: 556, “limit”: 634, “responseCode”: 200, “count”: 301, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Focus should red once.”, “messageTemplate”: “Take can conference blue floor.”, “field”: “Suffer doctor appear charge citizen.”, “parameter”: {}, “timestamp”: 265461878}], “currentPage”: 602, “size”: 606}

`api.customers.v1.customer.` `get_customer_by_id`(id: int, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Returns a Customer identified by its ID. (PUBLIC)

  Return type: | `dict`
  Parameters: | id (int) – Customer ID
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403 ObjectNotFoundException – on 404
  Returns: | {“offset”: 609, “limit”: 147, “responseCode”: 200, “count”: 572, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Kid myself magazine dog popular everyone paper message.”, “messageTemplate”: “Somebody expert suggest past once cover field leg.”, “field”: “Pay point even various necessary mind catch.”, “parameter”: {}, “timestamp”: 106395979}], “currentPage”: 888, “size”: 286}

`api.customers.v1.customer.` `get_customer_by_shortname`(shortName: str, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Returns a Customer identified by its shortname. (PUBLIC)

  Return type: | `dict`
  Parameters: | shortName (str) – Customer shortname
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403 ObjectNotFoundException – on 404
  Returns: | {“offset”: 363, “limit”: 928, “responseCode”: 200, “count”: 84, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Number career growth suddenly our stop.”, “messageTemplate”: “For party account myself whether practice system.”, “field”: “Be old relationship evening natural deep have.”, “parameter”: {}, “timestamp”: 693239719}], “currentPage”: 643, “size”: 969}

`api.customers.v1.customer.` `get_customer_logo_by_id`(id: int, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Returns a Customer logo by customer shortname. (PUBLIC)

  Return type: | `dict`
  Parameters: | id (int) – Customer ID
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403 ObjectNotFoundException – on 404
  Returns: | {}

`api.customers.v1.customer.` `get_customer_logo_by_shortname`(shortName: str, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Returns a Customer logo by customer shortname. (PUBLIC)

  Return type: | `dict`
  Parameters: | shortName (str) – Customer shortname
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403 ObjectNotFoundException – on 404
  Returns: | {}

`api.customers.v1.customer.` `list_customers`(parentID: list = None, service: list = None, keywords: list = None, keywordField: list = None, sortBy: list = None, offset: int = 0, limit: int = 25, keywordMatch: str = 'all', json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Returns customers defined by query parameters (PUBLIC)

  Return type: | `dict`
  Parameters: | parentID (list) – Search by parentID service (list) – Search by services keywords (list) – Search by keywords keywordField (list) – Set field strategy for keyword search sortBy (list) – Sort search result offset (int) – Skip a number of results limit (int) – Maximum number of returned results keywordMatch (str) – Set match strategy for keyword search
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403 ObjectNotFoundException – on 404
  Returns: | {“offset”: 407, “limit”: 770, “responseCode”: 200, “count”: 492, “data”: [{“id”: 138, “flags”: [“DISABLED”], “name”: “Jeffery Ellis”, “shortName”: “Tree poor window sure change lose short.”, “properties”: {“additionalProperties”: “Data stop check pretty spend.”}, “services”: [{“id”: 556, “name”: “Abigail Torres”, “description”: “Majority address mind true big cut.”}], “createdByUser”: {“id”: 102, “customerID”: 140, “userName”: “kathleenhanson”, “name”: “Michelle Anderson”}, “createdTimestamp”: 713403366, “lastUpdatedByUser”: {“id”: 196, “customerID”: 916, “userName”: “wwatson”, “name”: “Brian Pratt”}, “accountManager”: {“id”: 456, “customerID”: 125, “userName”: “lawrencenewton”, “name”: “Alexis Sandoval”}, “lastUpdatedTimestamp”: 816446285, “language”: “ENGLISH”}], “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Because relate international understand billion war.”, “messageTemplate”: “Authority white hair stay foot century.”, “field”: “Team him treat lay sense.”, “parameter”: {}, “timestamp”: 145581532}], “currentPage”: 492, “size”: 525}

`api.customers.v1.customer.` `reenable_customer`(id: int, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Reenable customer. (INTERNAL)

  Return type: | `dict`
  Parameters: | id (int) – Customer ID
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403 ObjectNotFoundException – on 404
  Returns: | {“offset”: 505, “limit”: 157, “responseCode”: 200, “count”: 234, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Tax eat term especially risk data.”, “messageTemplate”: “Stand low husband go total focus line.”, “field”: “Buy field certainly your sense author attack protect.”, “parameter”: {}, “timestamp”: 96152177}], “currentPage”: 317, “size”: 679}

`api.customers.v1.customer.` `remove_customer_service`(customerID: int, service: str, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Remove a service from a customer. (PUBLIC)

  Return type: | `dict`
  Parameters: | customerID (int) – Customer ID service (str) – Name of service to remove
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403 ObjectNotFoundException – on 404
  Returns: | {“offset”: 778, “limit”: 959, “responseCode”: 200, “count”: 132, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Weight human win ahead.”, “messageTemplate”: “Her heavy better.”, “field”: “Education Mr skill.”, “parameter”: {}, “timestamp”: 1271176969}], “currentPage”: 24, “size”: 487}

`api.customers.v1.customer.` `search_customers`(limit: int = None, offset: int = None, subCriteria: list = None, customerID: list = None, parentID: list = None, keywords: list = None, keywordMatchStrategy: str = None, keywordFieldStrategy: list = None, service: list = None, domain: list = None, sortBy: list = None, includeFlags: list = None, excludeFlags: list = None, includeDeleted: bool = 'False', exclude: bool = 'False', required: bool = 'False', json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Returns customers defined by CustomerSearchCriteria (PUBLIC)

  Return type: | `dict`
  Parameters: | limit (int) – Set this value to set max number of results. By default, no restriction on result set size. offset (int) – Set this value to skip the first (offset) objects. By default, return result from first object. subCriteria (list) – customerID (list) – Restrict search to data belonging to specified customers. parentID (list) – Search for customers by parent customer ID. keywords (list) – Search for customers by keywords. keywordMatchStrategy (str) – Defines the MatchStrategy for keywords (default match all keywords). keywordFieldStrategy (list) – Defines which fields will be searched by keywords (default all supported fields). service (list) – Search for customers having any of these services (service shortname). domain (list) – Search for customers in one of these domains (by domain id or name). sortBy (list) – List of properties to sort by (prefix with “-” to sort descending). includeFlags (list) – Only include objects which have includeFlags set. excludeFlags (list) – Exclude objects which have excludeFlags set. includeDeleted (bool) – Set to true to include deleted objects. By default, exclude deleted objects. exclude (bool) – Only relevant for subcriteria. If set to true, objects matching this subcriteria object will be excluded. required (bool) – Only relevant for subcriteria. If set to true, objects matching this subcriteria are required (AND-ed together with parent criteria).
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403 ObjectNotFoundException – on 404
  Returns: | {“offset”: 499, “limit”: 319, “responseCode”: 200, “count”: 182, “data”: [{“id”: 639, “flags”: [“ALLOW_MAIL_UPDATES”], “name”: “Jennifer Hurst”, “shortName”: “Nearly keep next hair.”, “properties”: {“additionalProperties”: “Citizen blood give.”}, “services”: [{“id”: 399, “name”: “Edward Freeman”, “description”: “Station tough sell century radio.”}], “createdByUser”: {“id”: 868, “customerID”: 429, “userName”: “matthew55”, “name”: “Rebecca George”}, “createdTimestamp”: 601974624, “lastUpdatedByUser”: {“id”: 975, “customerID”: 13, “userName”: “elizabethyoung”, “name”: “Jennifer Holt”}, “accountManager”: {“id”: 194, “customerID”: 773, “userName”: “swagner”, “name”: “Emily Taylor”}, “lastUpdatedTimestamp”: 899105483, “language”: “NORWEGIAN”}], “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Hour along public party wonder head discussion.”, “messageTemplate”: “He shoulder knowledge management.”, “field”: “Hard smile put large information into.”, “parameter”: {}, “timestamp”: 239493757}], “currentPage”: 957, “size”: 128}

`api.customers.v1.customer.` `update_customer`(id: int, name: str = None, shortName: str = None, language: str = None, addProperties: dict = None, deleteProperties: list = None, logoURL: str = None, timeZone: str = None, accountManagerID: int = None, addFeatures: list = None, deleteFeatures: list = None, type: str = None, excludeFromProduction: bool = 'False', json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Update a customer object. (PUBLIC)

  Return type: | `dict`
  Parameters: | id (int) – Customer ID name (str) – If set, change customer name to this value. => [sw{}$-().[]“‘_/,*+#:@!?;]* shortName (str) – If set, change customer shortname to this value (must be unique). => [a-zA-Z0-9_-.]* language (str) – If set, change customer language. addProperties (dict) – If set, add these properties. If the keys exist, they will be overwritten. => [sw{}$-().[]“‘_/,*+#:@!?;]* deleteProperties (list) – If set, remove properties with these keys. Missing keys are ignored. logoURL (str) – If set, change customer logo. On format data:image/jpeg;base64,BASE64STRING. => Sanitize by regex data:.* timeZone (str) – If set, change customer timezone to timezone with this name. accountManagerID (int) – If set, change customer account manmager to specified user. addFeatures (list) – If set, add these features to customer. deleteFeatures (list) – If set, remove these features from customer. type (str) – Customer type. If set to GROUP, this customer can have subcustomers. excludeFromProduction (bool) – If set, enable/disable customer as excluded from production
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403 ObjectNotFoundException – on 404
  Returns: | {“offset”: 888, “limit”: 813, “responseCode”: 200, “count”: 778, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Artist author kid democratic run.”, “messageTemplate”: “Act quickly represent walk.”, “field”: “Middle investment next watch leave board.”, “parameter”: {}, “timestamp”: 1441328791}], “currentPage”: 501, “size”: 283}

## api.customers.v1.location module

Autogenerated API

`api.customers.v1.location.` `get_customer_locations`(customerID: list = None, keywords: str = None, limit: int = 25, offset: int = 0, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Search locations by criteria (PUBLIC)

  Return type: | `dict`
  Parameters: | customerID (list) – Search by customerIDs keywords (str) – Search by keywords limit (int) – Limit result offset (int) – Offset result
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403 ObjectNotFoundException – on 404
  Returns: | {“offset”: 271, “limit”: 467, “responseCode”: 200, “count”: 101, “data”: [{“id”: 365, “name”: “Stephanie Lee”, “shortName”: “View lot will.”, “flags”: 523, “customerID”: 859, “internal”: false, “globalCustomer”: true, “dmz”: true, “zone”: “DMZ”, “external”: false}], “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Six cover minute arrive well bank.”, “messageTemplate”: “Stage station animal for until skin.”, “field”: “Character finally likely rich.”, “parameter”: {}, “timestamp”: 316796966}], “currentPage”: 760, “size”: 655}

## Module contents